@@ -17,14 +17,12 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-
 #include "historydialog.h"
 
 #include <QCheckBox>
 #include <QDateTime>
 #include <QDialogButtonBox>
 #include <QHeaderView>
-#include <QLayout>
 #include <QLineEdit>
 #include <QPushButton>
 #include <QRegExp>
@@ -33,41 +31,40 @@
 
 #include <KConfig>
 #include <KConfigGroup>
-#include <KLocalizedString>
 #include <KHelpClient>
+#include <KLocalizedString>
 
-#include "misc.h"
 #include "cvsserviceinterface.h"
+#include "misc.h"
 #include "progressdialog.h"
 
-
-static QDateTime parseDate(const QString& date, const QString& time, const QString& _offset)
+static QDateTime parseDate(const QString &date, const QString &time, const QString &_offset)
 {
     // cvs history only prints hhmm but fromString() needs hh:mm
-    QString offset( _offset );
-    if( !offset.contains(':') && offset.size() == 5 )
-        offset.insert( 3, ':' );
+    QString offset(_offset);
+    if (!offset.contains(':') && offset.size() == 5)
+        offset.insert(3, ':');
 
-    const QDateTime dt( QDateTime::fromString(date + 'T' + time + offset, Qt::ISODate) );
-    if ( !dt.isValid() )
-        return QDateTime();
+    const QDateTime dt(QDateTime::fromString(date + 'T' + time + offset, Qt::ISODate));
+    if (!dt.isValid())
+        return {};
 
     QDateTime dateTime;
-    dateTime.setTime_t( dt.toTime_t() );
+    dateTime.setTime_t(dt.toTime_t());
 
     return dateTime;
 }
 
-
 class HistoryItem : public QTreeWidgetItem
 {
 public:
-
     enum { Date, Event, Author, Revision, File, Path };
 
-    HistoryItem(QTreeWidget *parent, const QDateTime& date)
-        : QTreeWidgetItem(parent), m_date(date)
-    {}
+    HistoryItem(QTreeWidget *parent, const QDateTime &date)
+        : QTreeWidgetItem(parent)
+        , m_date(date)
+    {
+    }
 
     bool operator<(const QTreeWidgetItem &other) const override;
 
@@ -79,65 +76,56 @@ public:
     bool isOther();
 
 private:
-
     const QDateTime m_date;
 };
 
-
 bool HistoryItem::operator<(const QTreeWidgetItem &other) const
 {
-    const HistoryItem &item = static_cast<const HistoryItem &>(other);
+    const auto &item = static_cast<const HistoryItem &>(other);
 
-    switch ( treeWidget()->sortColumn() )
-    {
-    case Date    : return ::compare(m_date, item.m_date) == -1;
-    case Revision: return ::compareRevisions(text(Revision), item.text(Revision)) == -1;
+    switch (treeWidget()->sortColumn()) {
+    case Date:
+        return ::compare(m_date, item.m_date) == -1;
+    case Revision:
+        return ::compareRevisions(text(Revision), item.text(Revision)) == -1;
     }
 
     return QTreeWidgetItem::operator<(other);
 }
 
-
 QVariant HistoryItem::data(int column, int role) const
 {
-    if ( (role == Qt::DisplayRole) && (column == Date) )
+    if ((role == Qt::DisplayRole) && (column == Date))
         return QLocale().toString(m_date);
 
     return QTreeWidgetItem::data(column, role);
 }
 
-
 bool HistoryItem::isCommit()
 {
-    return text(1) == i18n("Commit, Modified ")
-        || text(1) == i18n("Commit, Added ")
-        || text(1) == i18n("Commit, Removed ");
+    return text(1) == i18n("Commit, Modified ") || text(1) == i18n("Commit, Added ") || text(1) == i18n("Commit, Removed ");
 }
 
-
 bool HistoryItem::isCheckout()
 {
     return text(1) == i18n("Checkout ");
 }
 
-
 bool HistoryItem::isTag()
 {
     return text(1) == i18n("Tag");
 }
 
-
 bool HistoryItem::isOther()
 {
     return !isCommit() && !isCheckout() && !isTag();
 }
 
-
-HistoryDialog::HistoryDialog(KConfig& cfg, QWidget *parent)
+HistoryDialog::HistoryDialog(KConfig &cfg, QWidget *parent)
     : QDialog(parent)
     , partConfig(cfg)
 {
-    QVBoxLayout *mainLayout = new QVBoxLayout;
+    auto mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
 
     listview = new QTreeWidget;
@@ -147,8 +135,7 @@ HistoryDialog::HistoryDialog(KConfig& cfg, QWidget *parent)
     listview->header()->setSortIndicatorShown(true);
     listview->setSortingEnabled(true);
     listview->sortByColumn(HistoryItem::Date, Qt::DescendingOrder);
-    listview->setHeaderLabels(QStringList() << i18n("Date") << i18n("Event") << i18n("Author")
-                                            << i18n("Revision") << i18n("File") << i18n("Repo Path"));
+    listview->setHeaderLabels(QStringList() << i18n("Date") << i18n("Event") << i18n("Author") << i18n("Revision") << i18n("File") << i18n("Repo Path"));
     listview->setFocus();
     mainLayout->addWidget(listview);
 
@@ -179,53 +166,40 @@ HistoryDialog::HistoryDialog(KConfig& cfg, QWidget *parent)
     dirname_edit = new QLineEdit;
     dirname_edit->setEnabled(false);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Help | QDialogButtonBox::Close);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Help | QDialogButtonBox::Close);
     connect(buttonBox, &QDialogButtonBox::helpRequested, this, &HistoryDialog::slotHelp);
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
-    connect( onlyuser_box, SIGNAL(toggled(bool)),
-             this, SLOT(toggled(bool)) );
-    connect( onlyfilenames_box, SIGNAL(toggled(bool)),
-             this,  SLOT(toggled(bool)) );
-    connect( onlydirnames_box, SIGNAL(toggled(bool)),
-             this, SLOT(toggled(bool)) );
-    connect( commit_box, SIGNAL(toggled(bool)),
-             this, SLOT(choiceChanged()) );
-    connect( checkout_box, SIGNAL(toggled(bool)),
-             this, SLOT(choiceChanged()) );
-    connect( tag_box, SIGNAL(toggled(bool)),
-             this, SLOT(choiceChanged()) );
-    connect( other_box, SIGNAL(toggled(bool)),
-             this, SLOT(choiceChanged()) );
-    connect( onlyuser_box, SIGNAL(toggled(bool)),
-             this, SLOT(choiceChanged()) );
-    connect( onlyfilenames_box, SIGNAL(toggled(bool)),
-             this, SLOT(choiceChanged()) );
-    connect( onlydirnames_box, SIGNAL(toggled(bool)),
-             this, SLOT(choiceChanged()) );
-    connect( user_edit, SIGNAL(returnPressed()),
-             this, SLOT(choiceChanged()) );
-    connect( filename_edit, SIGNAL(returnPressed()),
-             this, SLOT(choiceChanged()) );
-    connect( dirname_edit, SIGNAL(returnPressed()),
-             this, SLOT(choiceChanged()) );
+    connect(onlyuser_box, SIGNAL(toggled(bool)), this, SLOT(toggled(bool)));
+    connect(onlyfilenames_box, SIGNAL(toggled(bool)), this, SLOT(toggled(bool)));
+    connect(onlydirnames_box, SIGNAL(toggled(bool)), this, SLOT(toggled(bool)));
+    connect(commit_box, SIGNAL(toggled(bool)), this, SLOT(choiceChanged()));
+    connect(checkout_box, SIGNAL(toggled(bool)), this, SLOT(choiceChanged()));
+    connect(tag_box, SIGNAL(toggled(bool)), this, SLOT(choiceChanged()));
+    connect(other_box, SIGNAL(toggled(bool)), this, SLOT(choiceChanged()));
+    connect(onlyuser_box, SIGNAL(toggled(bool)), this, SLOT(choiceChanged()));
+    connect(onlyfilenames_box, SIGNAL(toggled(bool)), this, SLOT(choiceChanged()));
+    connect(onlydirnames_box, SIGNAL(toggled(bool)), this, SLOT(choiceChanged()));
+    connect(user_edit, SIGNAL(returnPressed()), this, SLOT(choiceChanged()));
+    connect(filename_edit, SIGNAL(returnPressed()), this, SLOT(choiceChanged()));
+    connect(dirname_edit, SIGNAL(returnPressed()), this, SLOT(choiceChanged()));
 
-    QGridLayout *grid = new QGridLayout;
-    mainLayout->addLayout( grid );
+    auto grid = new QGridLayout;
+    mainLayout->addLayout(grid);
     grid->setColumnStretch(0, 1);
     grid->setColumnStretch(1, 0);
     grid->setColumnStretch(2, 4);
     grid->setColumnStretch(3, 1);
-    grid->addWidget(commit_box,        0, 0);
-    grid->addWidget(checkout_box,      1, 0);
-    grid->addWidget(tag_box,           2, 0);
-    grid->addWidget(other_box,         3, 0);
-    grid->addWidget(onlyuser_box,      0, 1);
-    grid->addWidget(user_edit,         0, 2);
+    grid->addWidget(commit_box, 0, 0);
+    grid->addWidget(checkout_box, 1, 0);
+    grid->addWidget(tag_box, 2, 0);
+    grid->addWidget(other_box, 3, 0);
+    grid->addWidget(onlyuser_box, 0, 1);
+    grid->addWidget(user_edit, 0, 2);
     grid->addWidget(onlyfilenames_box, 1, 1);
-    grid->addWidget(filename_edit,     1, 2);
-    grid->addWidget(onlydirnames_box,  2, 1);
-    grid->addWidget(dirname_edit,      2, 2);
+    grid->addWidget(filename_edit, 1, 2);
+    grid->addWidget(onlydirnames_box, 2, 1);
+    grid->addWidget(dirname_edit, 2, 2);
 
     // no default button because "return" is needed to activate the filters (line edits)
     buttonBox->button(QDialogButtonBox::Help)->setAutoDefault(false);
@@ -242,7 +216,6 @@ HistoryDialog::HistoryDialog(KConfig& cfg, QWidget *parent)
     listview->header()->restoreState(state);
 }
 
-
 HistoryDialog::~HistoryDialog()
 {
     KConfigGroup cg(&partConfig, "HistoryDialog");
@@ -253,10 +226,9 @@ HistoryDialog::~HistoryDialog()
 
 void HistoryDialog::slotHelp()
 {
-  KHelpClient::invokeHelp(QLatin1String("browsinghistory"));
+    KHelpClient::invokeHelp(QLatin1String("browsinghistory"));
 }
 
-
 void HistoryDialog::choiceChanged()
 {
     const QString author(user_edit->text());
@@ -271,24 +243,18 @@ void HistoryDialog::choiceChanged()
     const bool filterByFile(onlyfilenames_box->isChecked() && !fileMatcher.isEmpty());
     const bool filterByPath(onlydirnames_box->isChecked() && !pathMatcher.isEmpty());
 
-    for (int i = 0; i < listview->topLevelItemCount(); i++)
-    {
-        HistoryItem *item = static_cast<HistoryItem*>(listview->topLevelItem(i));
+    for (int i = 0; i < listview->topLevelItemCount(); i++) {
+        auto item = static_cast<HistoryItem *>(listview->topLevelItem(i));
 
-        bool visible(   (showCommitEvents && item->isCommit())
-                     || (showCheckoutEvents && item->isCheckout())
-                     || (showTagEvents && item->isTag())
+        bool visible((showCommitEvents && item->isCommit()) || (showCheckoutEvents && item->isCheckout()) || (showTagEvents && item->isTag())
                      || (showOtherEvents && item->isOther()));
-        visible = visible
-            && (!filterByAuthor || author == item->text(HistoryItem::Author))
-            && (!filterByFile || item->text(HistoryItem::File).contains(fileMatcher))
-            && (!filterByPath || item->text(HistoryItem::Path).contains(pathMatcher));
+        visible = visible && (!filterByAuthor || author == item->text(HistoryItem::Author))
+            && (!filterByFile || item->text(HistoryItem::File).contains(fileMatcher)) && (!filterByPath || item->text(HistoryItem::Path).contains(pathMatcher));
 
         item->setHidden(!visible);
     }
 }
 
-
 void HistoryDialog::toggled(bool b)
 {
     QLineEdit *edit = 0;
@@ -301,88 +267,103 @@ void HistoryDialog::toggled(bool b)
         edit = dirname_edit;
 
     if (!edit)
-	return;
+        return;
 
     edit->setEnabled(b);
     if (b)
         edit->setFocus();
 }
 
-
-bool HistoryDialog::parseHistory(OrgKdeCervisia5CvsserviceCvsserviceInterface* cvsService)
+bool HistoryDialog::parseHistory(OrgKdeCervisia5CvsserviceCvsserviceInterface *cvsService)
 {
     setWindowTitle(i18n("CVS History"));
 
     QDBusReply<QDBusObjectPath> job = cvsService->history();
-    if( !job.isValid() )
+    if (!job.isValid())
         return false;
 
-    ProgressDialog dlg(this, "History",cvsService->service(), job, "history", i18n("CVS History"));
-    if( !dlg.execute() )
+    ProgressDialog dlg(this, "History", cvsService->service(), job, "history", i18n("CVS History"));
+    if (!dlg.execute())
         return false;
 
     QString line;
-    while( dlg.getLine(line) )
-    {
+    while (dlg.getLine(line)) {
         const QStringList list(splitLine(line));
         const int listSize(list.size());
-        if( listSize < 6)
+        if (listSize < 6)
             continue;
 
         QString cmd = list[0];
-        if( cmd.length() != 1 )
+        if (cmd.length() != 1)
             continue;
 
         int ncol;
         int cmd_code = cmd[0].toLatin1();
-        switch (cmd_code)
-        {
-            case 'O':
-            case 'F':
-            case 'E':
-                ncol = 8;
-                break;
-            default:
-                ncol = 10;
-                break;
+        switch (cmd_code) {
+        case 'O':
+        case 'F':
+        case 'E':
+            ncol = 8;
+            break;
+        default:
+            ncol = 10;
+            break;
         }
 
-        if( ncol != (int)list.count() )
+        if (ncol != (int)list.count())
             continue;
 
         QString event;
-        switch( cmd_code )
-        {
-            case 'O': event = i18n("Checkout ");         break;
-            case 'T': event = i18n("Tag ");              break;
-            case 'F': event = i18n("Release ");          break;
-            case 'W': event = i18n("Update, Deleted ");  break;
-            case 'U': event = i18n("Update, Copied ");   break;
-            case 'G': event = i18n("Update, Merged ");   break;
-            case 'C': event = i18n("Update, Conflict "); break;
-            case 'P': event = i18n("Update, Patched ");  break;
-            case 'M': event = i18n("Commit, Modified "); break;
-            case 'A': event = i18n("Commit, Added ");    break;
-            case 'R': event = i18n("Commit, Removed ");  break;
-            default:  event = i18n("Unknown ");
+        switch (cmd_code) {
+        case 'O':
+            event = i18n("Checkout ");
+            break;
+        case 'T':
+            event = i18n("Tag ");
+            break;
+        case 'F':
+            event = i18n("Release ");
+            break;
+        case 'W':
+            event = i18n("Update, Deleted ");
+            break;
+        case 'U':
+            event = i18n("Update, Copied ");
+            break;
+        case 'G':
+            event = i18n("Update, Merged ");
+            break;
+        case 'C':
+            event = i18n("Update, Conflict ");
+            break;
+        case 'P':
+            event = i18n("Update, Patched ");
+            break;
+        case 'M':
+            event = i18n("Commit, Modified ");
+            break;
+        case 'A':
+            event = i18n("Commit, Added ");
+            break;
+        case 'R':
+            event = i18n("Commit, Removed ");
+            break;
+        default:
+            event = i18n("Unknown ");
         }
 
         const QDateTime date(parseDate(list[1], list[2], list[3]));
 
-        HistoryItem *item = new HistoryItem(listview, date);
+        auto item = new HistoryItem(listview, date);
         item->setText(HistoryItem::Event, event);
         item->setText(HistoryItem::Author, list[4]);
-        if( ncol == 10 )
-        {
+        if (ncol == 10) {
             item->setText(HistoryItem::Revision, list[5]);
-            if( listSize >= 8 )
-            {
+            if (listSize >= 8) {
                 item->setText(HistoryItem::File, list[6]);
                 item->setText(HistoryItem::Path, list[7]);
             }
-        }
-        else
-        {
+        } else {
             item->setText(HistoryItem::Path, list[5]);
         }
     }
@@ -390,8 +371,6 @@ bool HistoryDialog::parseHistory(OrgKdeCervisia5CvsserviceCvsserviceInterface* c
     return true;
 }
 
-
-
 // Local Variables:
 // c-basic-offset: 4
 // End:
