@@ -18,43 +18,46 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-
 #include "repositorydialog.h"
 #include "debug.h"
 
-#include <QHBoxLayout>
-#include <QVBoxLayout>
-#include <QTreeWidget>
-#include <QHeaderView>
 #include <QDialogButtonBox>
+#include <QHBoxLayout>
+#include <QHeaderView>
 #include <QPushButton>
-#include <QDebug>
+#include <QTreeWidget>
+#include <QVBoxLayout>
 
-#include <kconfig.h>
-#include <kmessagebox.h>
-#include <kconfiggroup.h>
 #include <KConfigGroup>
 #include <KHelpClient>
 #include <KLocalizedString>
+#include <kconfig.h>
+#include <kconfiggroup.h>
+#include <kmessagebox.h>
 
 #include "addrepositorydialog.h"
-#include "cvsserviceinterface.h"
 #include "cvsloginjobinterface.h"
+#include "cvsserviceinterface.h"
 #include "misc.h"
 #include "progressdialog.h"
 #include "repositories.h"
 
-
 class RepositoryListItem : public QTreeWidgetItem
 {
 public:
-    RepositoryListItem(QTreeWidget* parent, const QString& repo, bool loggedin);
+    RepositoryListItem(QTreeWidget *parent, const QString &repo, bool loggedin);
 
-    void setRsh(const QString& rsh);
-    void setServer(const QString& server) { m_server = server; }
+    void setRsh(const QString &rsh);
+    void setServer(const QString &server)
+    {
+        m_server = server;
+    }
     void setCompression(int compression);
     void setIsLoggedIn(bool isLoggedIn);
-    void setRetrieveCvsignore(bool retrieve) { m_retrieveCvsignore = retrieve; }
+    void setRetrieveCvsignore(bool retrieve)
+    {
+        m_retrieveCvsignore = retrieve;
+    }
 
     QString repository() const
     {
@@ -63,39 +66,42 @@ public:
     QString rsh() const
     {
         QString str = text(1);
-        return (str.startsWith(QLatin1String("ext ("))
-                ? str.mid(5, str.length() - 6)
-                : QString());
+        return (str.startsWith(QLatin1String("ext (")) ? str.mid(5, str.length() - 6) : QString());
+    }
+    QString server() const
+    {
+        return m_server;
     }
-    QString server() const { return m_server; }
     int compression() const
     {
         bool ok;
         int n = text(2).toInt(&ok);
         return ok ? n : -1;
     }
-    bool isLoggedIn() const { return m_isLoggedIn; }
-    bool retrieveCvsignore() const { return m_retrieveCvsignore; }
+    bool isLoggedIn() const
+    {
+        return m_isLoggedIn;
+    }
+    bool retrieveCvsignore() const
+    {
+        return m_retrieveCvsignore;
+    }
 
 private:
     void changeLoginStatusColumn();
 
 private:
     QString m_server;
-    bool    m_isLoggedIn;
-    bool    m_retrieveCvsignore;
+    bool m_isLoggedIn;
+    bool m_retrieveCvsignore;
 };
 
-
-static bool LoginNeeded(const QString& repository)
+static bool LoginNeeded(const QString &repository)
 {
-    return repository.startsWith(QLatin1String(":pserver:")) ||
-           repository.startsWith(QLatin1String(":sspi:"));
+    return repository.startsWith(QLatin1String(":pserver:")) || repository.startsWith(QLatin1String(":sspi:"));
 }
 
-
-RepositoryListItem::RepositoryListItem(QTreeWidget* parent, const QString& repo,
-                                       bool loggedin)
+RepositoryListItem::RepositoryListItem(QTreeWidget *parent, const QString &repo, bool loggedin)
     : QTreeWidgetItem(parent)
     , m_isLoggedIn(loggedin)
 {
@@ -105,42 +111,35 @@ RepositoryListItem::RepositoryListItem(QTreeWidget* parent, const QString& repo,
     changeLoginStatusColumn();
 }
 
-
-void RepositoryListItem::setRsh(const QString& rsh)
+void RepositoryListItem::setRsh(const QString &rsh)
 {
     QString repo = repository();
     QString method;
 
-    if( repo.startsWith(QLatin1String(":pserver:")) )
+    if (repo.startsWith(QLatin1String(":pserver:")))
         method = "pserver";
-    else if( repo.startsWith(QLatin1String(":sspi:")) )
+    else if (repo.startsWith(QLatin1String(":sspi:")))
         method = "sspi";
-    else if( repo.contains(':') )
-    {
+    else if (repo.contains(':')) {
         method = "ext";
-        if( !rsh.isEmpty() )
-        {
+        if (!rsh.isEmpty()) {
             method += " (";
             method += rsh;
             method += ')';
         }
-    }
-    else
+    } else
         method = "local";
 
     setText(1, method);
 }
 
-
 void RepositoryListItem::setCompression(int compression)
 {
-    QString compressionStr = (compression >= 0) ? QString::number(compression)
-                                                : i18n("Default");
+    QString compressionStr = (compression >= 0) ? QString::number(compression) : i18n("Default");
 
     setText(2, compressionStr);
 }
 
-
 void RepositoryListItem::setIsLoggedIn(bool isLoggedIn)
 {
     m_isLoggedIn = isLoggedIn;
@@ -148,12 +147,11 @@ void RepositoryListItem::setIsLoggedIn(bool isLoggedIn)
     changeLoginStatusColumn();
 }
 
-
 void RepositoryListItem::changeLoginStatusColumn()
 {
     QString loginStatus;
 
-    if( LoginNeeded(repository()) )
+    if (LoginNeeded(repository()))
         loginStatus = m_isLoggedIn ? i18n("Logged in") : i18n("Not logged in");
     else
         loginStatus = i18n("No login required");
@@ -161,9 +159,10 @@ void RepositoryListItem::changeLoginStatusColumn()
     setText(3, loginStatus);
 }
 
-
-RepositoryDialog::RepositoryDialog(KConfig& cfg, OrgKdeCervisia5CvsserviceCvsserviceInterface* cvsService,
-                                   const QString& cvsServiceInterfaceName, QWidget* parent)
+RepositoryDialog::RepositoryDialog(KConfig &cfg,
+                                   OrgKdeCervisia5CvsserviceCvsserviceInterface *cvsService,
+                                   const QString &cvsServiceInterfaceName,
+                                   QWidget *parent)
     : QDialog(parent)
     , m_partConfig(cfg)
     , m_cvsService(cvsService)
@@ -172,16 +171,16 @@ RepositoryDialog::RepositoryDialog(KConfig& cfg, OrgKdeCervisia5CvsserviceCvsser
     setWindowTitle(i18n("Configure Access to Repositories"));
     setModal(true);
 
-    QVBoxLayout *mainLayout = new QVBoxLayout;
+    auto mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(okButton, SIGNAL(clicked()), this, SLOT(slotOk()));
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
-    QBoxLayout* hbox = new QHBoxLayout;
+    QBoxLayout *hbox = new QHBoxLayout;
     hbox->setContentsMargins(0, 0, 0, 0);
     mainLayout->addLayout(hbox);
 
@@ -190,36 +189,28 @@ RepositoryDialog::RepositoryDialog(KConfig& cfg, OrgKdeCervisia5CvsserviceCvsser
     m_repoList->setMinimumWidth(fontMetrics().width('0') * 60);
     m_repoList->setAllColumnsShowFocus(true);
     m_repoList->setRootIsDecorated(false);
-    m_repoList->setHeaderLabels(QStringList() << i18n("Repository") << i18n("Method")
-                                              << i18n("Compression") << i18n("Status"));
+    m_repoList->setHeaderLabels(QStringList() << i18n("Repository") << i18n("Method") << i18n("Compression") << i18n("Status"));
     m_repoList->setFocus();
 
-    connect(m_repoList, SIGNAL(itemDoubleClicked(QTreeWidgetItem*,int)),
-            this, SLOT(slotDoubleClicked(QTreeWidgetItem*,int)));
-    connect(m_repoList, SIGNAL(itemSelectionChanged()),
-            this,       SLOT(slotSelectionChanged()));
+    connect(m_repoList, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(slotDoubleClicked(QTreeWidgetItem *, int)));
+    connect(m_repoList, SIGNAL(itemSelectionChanged()), this, SLOT(slotSelectionChanged()));
 
-    QDialogButtonBox* actionbox = new QDialogButtonBox(Qt::Vertical);
-    QPushButton* addbutton = actionbox->addButton(i18n("Add..."), QDialogButtonBox::ActionRole);
+    auto actionbox = new QDialogButtonBox(Qt::Vertical);
+    QPushButton *addbutton = actionbox->addButton(i18n("Add..."), QDialogButtonBox::ActionRole);
     m_modifyButton = actionbox->addButton(i18n("Modify..."), QDialogButtonBox::ActionRole);
     m_removeButton = actionbox->addButton(i18n("Remove"), QDialogButtonBox::ActionRole);
-    m_loginButton  = actionbox->addButton(i18n("Login..."), QDialogButtonBox::ActionRole);
+    m_loginButton = actionbox->addButton(i18n("Login..."), QDialogButtonBox::ActionRole);
     m_logoutButton = actionbox->addButton(i18n("Logout"), QDialogButtonBox::ActionRole);
     hbox->addWidget(actionbox, 0);
 
     m_loginButton->setEnabled(false);
     m_logoutButton->setEnabled(false);
 
-    connect( addbutton, SIGNAL(clicked()),
-             this, SLOT(slotAddClicked()) );
-    connect( m_modifyButton, SIGNAL(clicked()),
-             this, SLOT(slotModifyClicked()) );
-    connect( m_removeButton, SIGNAL(clicked()),
-             this, SLOT(slotRemoveClicked()) );
-    connect( m_loginButton, SIGNAL(clicked()),
-             this, SLOT(slotLoginClicked()) );
-    connect( m_logoutButton, SIGNAL(clicked()),
-             this, SLOT(slotLogoutClicked()) );
+    connect(addbutton, SIGNAL(clicked()), this, SLOT(slotAddClicked()));
+    connect(m_modifyButton, SIGNAL(clicked()), this, SLOT(slotModifyClicked()));
+    connect(m_removeButton, SIGNAL(clicked()), this, SLOT(slotRemoveClicked()));
+    connect(m_loginButton, SIGNAL(clicked()), this, SLOT(slotLoginClicked()));
+    connect(m_logoutButton, SIGNAL(clicked()), this, SLOT(slotLogoutClicked()));
 
     // open cvs DBUS service configuration file
     m_serviceConfig = new KConfig("cvsservicerc");
@@ -227,13 +218,10 @@ RepositoryDialog::RepositoryDialog(KConfig& cfg, OrgKdeCervisia5CvsserviceCvsser
     readCvsPassFile();
     readConfigFile();
 
-    if (QTreeWidgetItem *item = m_repoList->topLevelItem(0))
-    {
+    if (QTreeWidgetItem *item = m_repoList->topLevelItem(0)) {
         m_repoList->setCurrentItem(item);
         item->setSelected(true);
-    }
-    else
-    {
+    } else {
         // we have no item so disable modify and remove button
         slotSelectionChanged();
     }
@@ -251,7 +239,6 @@ RepositoryDialog::RepositoryDialog(KConfig& cfg, OrgKdeCervisia5CvsserviceCvsser
     mainLayout->addWidget(buttonBox);
 }
 
-
 RepositoryDialog::~RepositoryDialog()
 {
     KConfigGroup cg(&m_partConfig, "RepositoryDialog");
@@ -262,15 +249,13 @@ RepositoryDialog::~RepositoryDialog()
     delete m_serviceConfig;
 }
 
-
 void RepositoryDialog::readCvsPassFile()
 {
     QStringList list = Repositories::readCvsPassFile();
-    Q_FOREACH(const QString& it, list)
-        (void) new RepositoryListItem(m_repoList, it, true);
+    Q_FOREACH (const QString &it, list)
+        (void)new RepositoryListItem(m_repoList, it, true);
 }
 
-
 void RepositoryDialog::readConfigFile()
 {
     QStringList list = Repositories::readConfigFile();
@@ -279,23 +264,21 @@ void RepositoryDialog::readConfigFile()
     for (int i = 0; i < m_repoList->topLevelItemCount(); i++)
         list.removeAll(m_repoList->topLevelItem(i)->text(0));
 
-    Q_FOREACH(const QString& it, list)
+    Q_FOREACH (const QString &it, list)
         new RepositoryListItem(m_repoList, it, false);
 
     // Now look for the used methods
-    for (int i = 0; i < m_repoList->topLevelItemCount(); i++)
-    {
-        RepositoryListItem* ritem = static_cast<RepositoryListItem*>(m_repoList->topLevelItem(i));
+    for (int i = 0; i < m_repoList->topLevelItemCount(); i++) {
+        auto ritem = static_cast<RepositoryListItem *>(m_repoList->topLevelItem(i));
 
         // read entries from cvs DBUS service configuration
-        const KConfigGroup repoGroup = m_serviceConfig->group(QLatin1String("Repository-") +
-                                                              ritem->repository());
+        const KConfigGroup repoGroup = m_serviceConfig->group(QLatin1String("Repository-") + ritem->repository());
 
         qCDebug(log_cervisia) << "repository=" << ritem->repository();
 
-        QString rsh       = repoGroup.readEntry("rsh", QString());
-        QString server    = repoGroup.readEntry("cvs_server", QString());
-        int compression   = repoGroup.readEntry("Compression", -1);
+        QString rsh = repoGroup.readEntry("rsh", QString());
+        QString server = repoGroup.readEntry("cvs_server", QString());
+        int compression = repoGroup.readEntry("Compression", -1);
         bool retrieveFile = repoGroup.readEntry("RetrieveCvsignore", false);
 
         ritem->setRsh(rsh);
@@ -322,9 +305,8 @@ void RepositoryDialog::slotOk()
     KConfigGroup reposGroup = m_partConfig.group("Repositories");
     reposGroup.writeEntry("Repos", list);
 
-    for (int i = 0; i < m_repoList->topLevelItemCount(); i++)
-    {
-        RepositoryListItem* ritem = static_cast<RepositoryListItem*>(m_repoList->topLevelItem(i));
+    for (int i = 0; i < m_repoList->topLevelItemCount(); i++) {
+        auto ritem = static_cast<RepositoryListItem *>(m_repoList->topLevelItem(i));
 
         // write entries to cvs DBUS service configuration
         writeRepositoryData(ritem);
@@ -336,28 +318,25 @@ void RepositoryDialog::slotOk()
     QDialog::accept();
 }
 
-
 void RepositoryDialog::slotAddClicked()
 {
     AddRepositoryDialog dlg(m_partConfig, QString(), this);
     // default compression level
     dlg.setCompression(-1);
-    if( dlg.exec() )
-    {
-        QString repo      = Cervisia::NormalizeRepository(dlg.repository());
-        QString rsh       = dlg.rsh();
-        QString server    = dlg.server();
-        int compression   = dlg.compression();
+    if (dlg.exec()) {
+        QString repo = Cervisia::NormalizeRepository(dlg.repository());
+        QString rsh = dlg.rsh();
+        QString server = dlg.server();
+        int compression = dlg.compression();
         bool retrieveFile = dlg.retrieveCvsignoreFile();
 
         for (int i = 0; i < m_repoList->topLevelItemCount(); i++)
-            if( m_repoList->topLevelItem(i)->text(0) == repo )
-            {
+            if (m_repoList->topLevelItem(i)->text(0) == repo) {
                 KMessageBox::information(this, i18n("This repository is already known."));
                 return;
             }
 
-        RepositoryListItem* ritem = new RepositoryListItem(m_repoList, repo, false);
+        auto ritem = new RepositoryListItem(m_repoList, repo, false);
         ritem->setRsh(rsh);
         ritem->setCompression(compression);
         ritem->setRetrieveCvsignore(retrieveFile);
@@ -370,36 +349,33 @@ void RepositoryDialog::slotAddClicked()
     }
 }
 
-
 void RepositoryDialog::slotModifyClicked()
 {
     slotDoubleClicked(m_repoList->currentItem(), 0);
 }
 
-
 void RepositoryDialog::slotRemoveClicked()
 {
     // logout from pserver accounts so that they don't
     // get re-added because of the .cvspass file. (BR #51129)
-    if( m_logoutButton->isEnabled() )
+    if (m_logoutButton->isEnabled())
         slotLogoutClicked();
 
     delete m_repoList->currentItem();
 }
 
-
 void RepositoryDialog::slotDoubleClicked(QTreeWidgetItem *item, int column)
 {
     Q_UNUSED(column)
 
-    if( !item )
+    if (!item)
         return;
 
-    RepositoryListItem* ritem = static_cast<RepositoryListItem*>(item);
-    QString repo      = ritem->repository();
-    QString rsh       = ritem->rsh();
-    QString server    = ritem->server();
-    int compression   = ritem->compression();
+    auto ritem = static_cast<RepositoryListItem *>(item);
+    QString repo = ritem->repository();
+    QString rsh = ritem->rsh();
+    QString server = ritem->server();
+    int compression = ritem->compression();
     bool retrieveFile = ritem->retrieveCvsignore();
 
     AddRepositoryDialog dlg(m_partConfig, repo, this);
@@ -408,8 +384,7 @@ void RepositoryDialog::slotDoubleClicked(QTreeWidgetItem *item, int column)
     dlg.setServer(server);
     dlg.setCompression(compression);
     dlg.setRetrieveCvsignoreFile(retrieveFile);
-    if( dlg.exec() )
-    {
+    if (dlg.exec()) {
         ritem->setRsh(dlg.rsh());
         ritem->setServer(dlg.server());
         ritem->setCompression(dlg.compression());
@@ -423,27 +398,25 @@ void RepositoryDialog::slotDoubleClicked(QTreeWidgetItem *item, int column)
     }
 }
 
-
 void RepositoryDialog::slotLoginClicked()
 {
-    RepositoryListItem* item = (RepositoryListItem*)m_repoList->currentItem();
-    if( !item )
+    auto item = (RepositoryListItem *)m_repoList->currentItem();
+    if (!item)
         return;
 
     qCDebug(log_cervisia) << "repo=" << item->repository();
 
     QDBusReply<QDBusObjectPath> job = m_cvsService->login(item->repository());
-    if( !job.isValid() )
+    if (!job.isValid())
         // TODO: error handling
         return;
     QDBusObjectPath jobPath = job;
-    OrgKdeCervisia5CvsserviceCvsloginjobInterface cvsloginjobinterface(m_cvsServiceInterfaceName,jobPath.path(),QDBusConnection::sessionBus(), this);
+    OrgKdeCervisia5CvsserviceCvsloginjobInterface cvsloginjobinterface(m_cvsServiceInterfaceName, jobPath.path(), QDBusConnection::sessionBus(), this);
     QDBusReply<bool> reply = cvsloginjobinterface.execute();
     bool success = false;
-    if(reply.isValid())
+    if (reply.isValid())
         success = reply;
-    if( !success )
-    {
+    if (!success) {
         QDBusReply<QStringList> ret = cvsloginjobinterface.output();
 
         QStringList output = ret;
@@ -455,31 +428,29 @@ void RepositoryDialog::slotLoginClicked()
     slotSelectionChanged();
 }
 
-
 void RepositoryDialog::slotLogoutClicked()
 {
-    RepositoryListItem* item = (RepositoryListItem*)m_repoList->currentItem();
-    if( !item )
+    auto item = (RepositoryListItem *)m_repoList->currentItem();
+    if (!item)
         return;
 
     QDBusReply<QDBusObjectPath> job = m_cvsService->logout(item->repository());
-    if( !job.isValid() )
+    if (!job.isValid())
         // TODO: error handling
         return;
 
-    ProgressDialog dlg(this, "Logout", m_cvsService->service(),job, "logout", i18n("CVS Logout"));
-    if( !dlg.execute() )
+    ProgressDialog dlg(this, "Logout", m_cvsService->service(), job, "logout", i18n("CVS Logout"));
+    if (!dlg.execute())
         return;
 
     item->setIsLoggedIn(false);
     slotSelectionChanged();
 }
 
-
 void RepositoryDialog::slotSelectionChanged()
 {
     // retrieve the selected item
-    RepositoryListItem* item = (RepositoryListItem*)m_repoList->currentItem();
+    auto item = (RepositoryListItem *)m_repoList->currentItem();
 
     // is an item in the list view selected?
     bool isItemSelected = (item != 0);
@@ -488,12 +459,11 @@ void RepositoryDialog::slotSelectionChanged()
     m_loginButton->setEnabled(isItemSelected);
     m_logoutButton->setEnabled(isItemSelected);
 
-    if( !isItemSelected )
+    if (!isItemSelected)
         return;
 
     // is this a pserver repository?
-    if( !LoginNeeded(item->repository()) )
-    {
+    if (!LoginNeeded(item->repository())) {
         m_loginButton->setEnabled(false);
         m_logoutButton->setEnabled(false);
         return;
@@ -505,12 +475,10 @@ void RepositoryDialog::slotSelectionChanged()
     m_logoutButton->setEnabled(isLoggedIn);
 }
 
-
-void RepositoryDialog::writeRepositoryData(RepositoryListItem* item)
+void RepositoryDialog::writeRepositoryData(RepositoryListItem *item)
 {
     // write entries to cvs DBUS service configuration
-    KConfigGroup repoGroup = m_serviceConfig->group(QLatin1String("Repository-") +
-                              item->repository());
+    KConfigGroup repoGroup = m_serviceConfig->group(QLatin1String("Repository-") + item->repository());
 
     qCDebug(log_cervisia) << "repository=" << item->repository();
 
@@ -520,5 +488,4 @@ void RepositoryDialog::writeRepositoryData(RepositoryListItem* item)
     repoGroup.writeEntry("RetrieveCvsignore", item->retrieveCvsignore());
 }
 
-
 // kate: space-indent on; indent-width 4; replace-tabs on;
