@@ -17,45 +17,38 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-
 #include "watchdialog.h"
 
+#include <QGridLayout>
 #include <qbuttongroup.h>
 #include <qcheckbox.h>
 #include <qlabel.h>
 #include <qradiobutton.h>
-#include <QGridLayout>
-#include <QBoxLayout>
-#include <QGroupBox>
 
-#include <KConfigGroup>
-#include <KLocalizedString>
 #include <KHelpClient>
+#include <KLocalizedString>
 
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QVBoxLayout>
 
-
 WatchDialog::WatchDialog(ActionType action, QWidget *parent)
     : QDialog(parent)
 {
-    setWindowTitle( (action==Add)? i18n("CVS Watch Add") : i18n("CVS Watch Remove") );
+    setWindowTitle((action == Add) ? i18n("CVS Watch Add") : i18n("CVS Watch Remove"));
     setModal(true);
 
-    QVBoxLayout *mainLayout = new QVBoxLayout;
+    auto mainLayout = new QVBoxLayout;
     setLayout(mainLayout);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
     connect(buttonBox, &QDialogButtonBox::helpRequested, this, &WatchDialog::slotHelp);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, SIGNAL(accepted()), this, SLOT(accept()));
     connect(buttonBox, SIGNAL(rejected()), this, SLOT(reject()));
 
-    QLabel *textlabel = new QLabel
-	( (action==Add)? i18n("Add watches for the following events:")
-          :  i18n("Remove watches for the following events:"));
+    auto textlabel = new QLabel((action == Add) ? i18n("Add watches for the following events:") : i18n("Remove watches for the following events:"));
     mainLayout->addWidget(textlabel);
 
     all_button = new QRadioButton(i18n("&All"));
@@ -66,7 +59,7 @@ WatchDialog::WatchDialog(ActionType action, QWidget *parent)
     only_button = new QRadioButton(i18n("&Only:"));
     mainLayout->addWidget(only_button);
 
-    QGridLayout *eventslayout = new QGridLayout();
+    auto eventslayout = new QGridLayout();
     mainLayout->addLayout(eventslayout);
     eventslayout->addItem(new QSpacerItem(20, 0), 0, 0);
     eventslayout->setColumnStretch(0, 0);
@@ -84,7 +77,7 @@ WatchDialog::WatchDialog(ActionType action, QWidget *parent)
     uneditbox->setEnabled(false);
     eventslayout->addWidget(uneditbox, 2, 1);
 
-    QButtonGroup* group = new QButtonGroup(this);
+    auto group = new QButtonGroup(this);
     group->addButton(all_button);
     group->addButton(only_button);
 
@@ -97,28 +90,25 @@ WatchDialog::WatchDialog(ActionType action, QWidget *parent)
 
 void WatchDialog::slotHelp()
 {
-  KHelpClient::invokeHelp(QLatin1String("watches"));
+    KHelpClient::invokeHelp(QLatin1String("watches"));
 }
 
-
 WatchDialog::Events WatchDialog::events() const
 {
     Events res = None;
     if (all_button->isChecked())
         res = All;
-    else
-        {
-            if (commitbox->isChecked())
-                res = Events(res | Commits);
-            if (editbox->isChecked())
-                res = Events(res | Edits);
-            if (uneditbox->isChecked())
-                res = Events(res | Unedits);
-        }
+    else {
+        if (commitbox->isChecked())
+            res = Events(res | Commits);
+        if (editbox->isChecked())
+            res = Events(res | Edits);
+        if (uneditbox->isChecked())
+            res = Events(res | Unedits);
+    }
     return res;
 }
 
-
 // Local Variables:
 // c-basic-offset: 4
 // End:
